@@ -1,5 +1,6 @@
 import numpy as np
-from .luriegold import luriegold
+
+from .luriegold import approximate_correlation_matrix
 
 
 def illmat(n_dim: int, random_state: int = None) -> np.ndarray:
@@ -21,15 +22,16 @@ def illmat(n_dim: int, random_state: int = None) -> np.ndarray:
     return np.eye(n_dim) + tmp + tmp.T
 
 
-def randcorr(n_obs: int, n_vars: int, rho: np.ndarray = None,
-             random_state: int = None) -> np.ndarray:
+def randcorr(
+    n_obs: int, n_vars: int, rho: np.ndarray = None, random_state: int = None
+) -> np.ndarray:
     """Generate correlated random numbers"""
     if random_state:
         np.random.seed(random_state)
     # Generate a random correlation matrix if no supplied
     if rho is None:
         mat = illmat(n_vars)
-        rho = luriegold(mat)
+        rho = approximate_correlation_matrix(mat)
     # Generate N(0,1) distributed random numbers
     X = np.random.standard_normal(size=(n_obs, n_vars))
     # Cholesky trick
